<?php

return [
    'Names' => [
        'af' => 'Afrikaans',
        'af_NA' => 'Afrikaans (Namibia)',
        'af_ZA' => 'Afrikaans (Afrika Selatan)',
        'ak' => 'Akan',
        'ak_GH' => 'Akan (Ghana)',
        'am' => 'Amharik',
        'am_ET' => 'Amharik (Etiopia)',
        'ar' => 'Arab',
        'ar_001' => 'Arab (Dunia)',
        'ar_AE' => 'Arab (Uni Emirat Arab)',
        'ar_BH' => 'Arab (Bahrain)',
        'ar_DJ' => 'Arab (Jibuti)',
        'ar_DZ' => 'Arab (Aljazair)',
        'ar_EG' => 'Arab (Mesir)',
        'ar_EH' => 'Arab (Sahara Barat)',
        'ar_ER' => 'Arab (Eritrea)',
        'ar_IL' => 'Arab (Israel)',
        'ar_IQ' => 'Arab (Irak)',
        'ar_JO' => 'Arab (Yordania)',
        'ar_KM' => 'Arab (Komoro)',
        'ar_KW' => 'Arab (Kuwait)',
        'ar_LB' => 'Arab (Lebanon)',
        'ar_LY' => 'Arab (Libya)',
        'ar_MA' => 'Arab (Maroko)',
        'ar_MR' => 'Arab (Mauritania)',
        'ar_OM' => 'Arab (Oman)',
        'ar_PS' => 'Arab (Wilayah Palestina)',
        'ar_QA' => 'Arab (Qatar)',
        'ar_SA' => 'Arab (Arab Saudi)',
        'ar_SD' => 'Arab (Sudan)',
        'ar_SO' => 'Arab (Somalia)',
        'ar_SS' => 'Arab (Sudan Selatan)',
        'ar_SY' => 'Arab (Suriah)',
        'ar_TD' => 'Arab (Chad)',
        'ar_TN' => 'Arab (Tunisia)',
        'ar_YE' => 'Arab (Yaman)',
        'as' => 'Assam',
        'as_IN' => 'Assam (India)',
        'az' => 'Azerbaijani',
        'az_AZ' => 'Azerbaijani (Azerbaijan)',
        'az_Cyrl' => 'Azerbaijani (Sirilik)',
        'az_Cyrl_AZ' => 'Azerbaijani (Sirilik, Azerbaijan)',
        'az_Latn' => 'Azerbaijani (Latin)',
        'az_Latn_AZ' => 'Azerbaijani (Latin, Azerbaijan)',
        'be' => 'Belarusia',
        'be_BY' => 'Belarusia (Belarus)',
        'bg' => 'Bulgaria',
        'bg_BG' => 'Bulgaria (Bulgaria)',
        'bm' => 'Bambara',
        'bm_ML' => 'Bambara (Mali)',
        'bn' => 'Bengali',
        'bn_BD' => 'Bengali (Bangladesh)',
        'bn_IN' => 'Bengali (India)',
        'bo' => 'Tibet',
        'bo_CN' => 'Tibet (Tiongkok)',
        'bo_IN' => 'Tibet (India)',
        'br' => 'Breton',
        'br_FR' => 'Breton (Prancis)',
        'bs' => 'Bosnia',
        'bs_BA' => 'Bosnia (Bosnia dan Herzegovina)',
        'bs_Cyrl' => 'Bosnia (Sirilik)',
        'bs_Cyrl_BA' => 'Bosnia (Sirilik, Bosnia dan Herzegovina)',
        'bs_Latn' => 'Bosnia (Latin)',
        'bs_Latn_BA' => 'Bosnia (Latin, Bosnia dan Herzegovina)',
        'ca' => 'Katalan',
        'ca_AD' => 'Katalan (Andorra)',
        'ca_ES' => 'Katalan (Spanyol)',
        'ca_FR' => 'Katalan (Prancis)',
        'ca_IT' => 'Katalan (Italia)',
        'ce' => 'Chechen',
        'ce_RU' => 'Chechen (Rusia)',
        'cs' => 'Cheska',
        'cs_CZ' => 'Cheska (Ceko)',
        'cv' => 'Chuvash',
        'cv_RU' => 'Chuvash (Rusia)',
        'cy' => 'Welsh',
        'cy_GB' => 'Welsh (Inggris Raya)',
        'da' => 'Dansk',
        'da_DK' => 'Dansk (Denmark)',
        'da_GL' => 'Dansk (Greenland)',
        'de' => 'Jerman',
        'de_AT' => 'Jerman (Austria)',
        'de_BE' => 'Jerman (Belgia)',
        'de_CH' => 'Jerman (Swiss)',
        'de_DE' => 'Jerman (Jerman)',
        'de_IT' => 'Jerman (Italia)',
        'de_LI' => 'Jerman (Liechtenstein)',
        'de_LU' => 'Jerman (Luksemburg)',
        'dz' => 'Dzongkha',
        'dz_BT' => 'Dzongkha (Bhutan)',
        'ee' => 'Ewe',
        'ee_GH' => 'Ewe (Ghana)',
        'ee_TG' => 'Ewe (Togo)',
        'el' => 'Yunani',
        'el_CY' => 'Yunani (Siprus)',
        'el_GR' => 'Yunani (Yunani)',
        'en' => 'Inggris',
        'en_001' => 'Inggris (Dunia)',
        'en_150' => 'Inggris (Eropa)',
        'en_AE' => 'Inggris (Uni Emirat Arab)',
        'en_AG' => 'Inggris (Antigua dan Barbuda)',
        'en_AI' => 'Inggris (Anguilla)',
        'en_AS' => 'Inggris (Samoa Amerika)',
        'en_AT' => 'Inggris (Austria)',
        'en_AU' => 'Inggris (Australia)',
        'en_BB' => 'Inggris (Barbados)',
        'en_BE' => 'Inggris (Belgia)',
        'en_BI' => 'Inggris (Burundi)',
        'en_BM' => 'Inggris (Bermuda)',
        'en_BS' => 'Inggris (Bahama)',
        'en_BW' => 'Inggris (Botswana)',
        'en_BZ' => 'Inggris (Belize)',
        'en_CA' => 'Inggris (Kanada)',
        'en_CC' => 'Inggris (Kepulauan Cocos [Keeling])',
        'en_CH' => 'Inggris (Swiss)',
        'en_CK' => 'Inggris (Kepulauan Cook)',
        'en_CM' => 'Inggris (Kamerun)',
        'en_CX' => 'Inggris (Pulau Natal)',
        'en_CY' => 'Inggris (Siprus)',
        'en_DE' => 'Inggris (Jerman)',
        'en_DK' => 'Inggris (Denmark)',
        'en_DM' => 'Inggris (Dominika)',
        'en_ER' => 'Inggris (Eritrea)',
        'en_FI' => 'Inggris (Finlandia)',
        'en_FJ' => 'Inggris (Fiji)',
        'en_FK' => 'Inggris (Kepulauan Falkland)',
        'en_FM' => 'Inggris (Mikronesia)',
        'en_GB' => 'Inggris (Inggris Raya)',
        'en_GD' => 'Inggris (Grenada)',
        'en_GG' => 'Inggris (Guernsey)',
        'en_GH' => 'Inggris (Ghana)',
        'en_GI' => 'Inggris (Gibraltar)',
        'en_GM' => 'Inggris (Gambia)',
        'en_GU' => 'Inggris (Guam)',
        'en_GY' => 'Inggris (Guyana)',
        'en_HK' => 'Inggris (Hong Kong DAK Tiongkok)',
        'en_IE' => 'Inggris (Irlandia)',
        'en_IL' => 'Inggris (Israel)',
        'en_IM' => 'Inggris (Pulau Man)',
        'en_IN' => 'Inggris (India)',
        'en_IO' => 'Inggris (Wilayah Inggris di Samudra Hindia)',
        'en_JE' => 'Inggris (Jersey)',
        'en_JM' => 'Inggris (Jamaika)',
        'en_KE' => 'Inggris (Kenya)',
        'en_KI' => 'Inggris (Kiribati)',
        'en_KN' => 'Inggris (Saint Kitts dan Nevis)',
        'en_KY' => 'Inggris (Kepulauan Cayman)',
        'en_LC' => 'Inggris (Saint Lucia)',
        'en_LR' => 'Inggris (Liberia)',
        'en_LS' => 'Inggris (Lesotho)',
        'en_MG' => 'Inggris (Madagaskar)',
        'en_MH' => 'Inggris (Kepulauan Marshall)',
        'en_MO' => 'Inggris (Makau DAK Tiongkok)',
        'en_MP' => 'Inggris (Kepulauan Mariana Utara)',
        'en_MS' => 'Inggris (Montserrat)',
        'en_MT' => 'Inggris (Malta)',
        'en_MU' => 'Inggris (Mauritius)',
        'en_MV' => 'Inggris (Maladewa)',
        'en_MW' => 'Inggris (Malawi)',
        'en_MY' => 'Inggris (Malaysia)',
        'en_NA' => 'Inggris (Namibia)',
        'en_NF' => 'Inggris (Kepulauan Norfolk)',
        'en_NG' => 'Inggris (Nigeria)',
        'en_NL' => 'Inggris (Belanda)',
        'en_NR' => 'Inggris (Nauru)',
        'en_NU' => 'Inggris (Niue)',
        'en_NZ' => 'Inggris (Selandia Baru)',
        'en_PG' => 'Inggris (Papua Nugini)',
        'en_PH' => 'Inggris (Filipina)',
        'en_PK' => 'Inggris (Pakistan)',
        'en_PN' => 'Inggris (Kepulauan Pitcairn)',
        'en_PR' => 'Inggris (Puerto Riko)',
        'en_PW' => 'Inggris (Palau)',
        'en_RW' => 'Inggris (Rwanda)',
        'en_SB' => 'Inggris (Kepulauan Solomon)',
        'en_SC' => 'Inggris (Seychelles)',
        'en_SD' => 'Inggris (Sudan)',
        'en_SE' => 'Inggris (Swedia)',
        'en_SG' => 'Inggris (Singapura)',
        'en_SH' => 'Inggris (Saint Helena)',
        'en_SI' => 'Inggris (Slovenia)',
        'en_SL' => 'Inggris (Sierra Leone)',
        'en_SS' => 'Inggris (Sudan Selatan)',
        'en_SX' => 'Inggris (Sint Maarten)',
        'en_SZ' => 'Inggris (eSwatini)',
        'en_TC' => 'Inggris (Kepulauan Turks dan Caicos)',
        'en_TK' => 'Inggris (Tokelau)',
        'en_TO' => 'Inggris (Tonga)',
        'en_TT' => 'Inggris (Trinidad dan Tobago)',
        'en_TV' => 'Inggris (Tuvalu)',
        'en_TZ' => 'Inggris (Tanzania)',
        'en_UG' => 'Inggris (Uganda)',
        'en_UM' => 'Inggris (Kepulauan Terluar AS)',
        'en_US' => 'Inggris (Amerika Serikat)',
        'en_VC' => 'Inggris (Saint Vincent dan Grenadine)',
        'en_VG' => 'Inggris (Kepulauan Virgin Britania Raya)',
        'en_VI' => 'Inggris (Kepulauan Virgin Amerika Serikat)',
        'en_VU' => 'Inggris (Vanuatu)',
        'en_WS' => 'Inggris (Samoa)',
        'en_ZA' => 'Inggris (Afrika Selatan)',
        'en_ZM' => 'Inggris (Zambia)',
        'en_ZW' => 'Inggris (Zimbabwe)',
        'eo' => 'Esperanto',
        'eo_001' => 'Esperanto (Dunia)',
        'es' => 'Spanyol',
        'es_419' => 'Spanyol (Amerika Latin)',
        'es_AR' => 'Spanyol (Argentina)',
        'es_BO' => 'Spanyol (Bolivia)',
        'es_BR' => 'Spanyol (Brasil)',
        'es_BZ' => 'Spanyol (Belize)',
        'es_CL' => 'Spanyol (Cile)',
        'es_CO' => 'Spanyol (Kolombia)',
        'es_CR' => 'Spanyol (Kosta Rika)',
        'es_CU' => 'Spanyol (Kuba)',
        'es_DO' => 'Spanyol (Republik Dominika)',
        'es_EC' => 'Spanyol (Ekuador)',
        'es_ES' => 'Spanyol (Spanyol)',
        'es_GQ' => 'Spanyol (Guinea Ekuatorial)',
        'es_GT' => 'Spanyol (Guatemala)',
        'es_HN' => 'Spanyol (Honduras)',
        'es_MX' => 'Spanyol (Meksiko)',
        'es_NI' => 'Spanyol (Nikaragua)',
        'es_PA' => 'Spanyol (Panama)',
        'es_PE' => 'Spanyol (Peru)',
        'es_PH' => 'Spanyol (Filipina)',
        'es_PR' => 'Spanyol (Puerto Riko)',
        'es_PY' => 'Spanyol (Paraguay)',
        'es_SV' => 'Spanyol (El Salvador)',
        'es_US' => 'Spanyol (Amerika Serikat)',
        'es_UY' => 'Spanyol (Uruguay)',
        'es_VE' => 'Spanyol (Venezuela)',
        'et' => 'Esti',
        'et_EE' => 'Esti (Estonia)',
        'eu' => 'Basque',
        'eu_ES' => 'Basque (Spanyol)',
        'fa' => 'Persia',
        'fa_AF' => 'Persia (Afganistan)',
        'fa_IR' => 'Persia (Iran)',
        'ff' => 'Fula',
        'ff_Adlm' => 'Fula (Adlam)',
        'ff_Adlm_BF' => 'Fula (Adlam, Burkina Faso)',
        'ff_Adlm_CM' => 'Fula (Adlam, Kamerun)',
        'ff_Adlm_GH' => 'Fula (Adlam, Ghana)',
        'ff_Adlm_GM' => 'Fula (Adlam, Gambia)',
        'ff_Adlm_GN' => 'Fula (Adlam, Guinea)',
        'ff_Adlm_GW' => 'Fula (Adlam, Guinea-Bissau)',
        'ff_Adlm_LR' => 'Fula (Adlam, Liberia)',
        'ff_Adlm_MR' => 'Fula (Adlam, Mauritania)',
        'ff_Adlm_NE' => 'Fula (Adlam, Niger)',
        'ff_Adlm_NG' => 'Fula (Adlam, Nigeria)',
        'ff_Adlm_SL' => 'Fula (Adlam, Sierra Leone)',
        'ff_Adlm_SN' => 'Fula (Adlam, Senegal)',
        'ff_CM' => 'Fula (Kamerun)',
        'ff_GN' => 'Fula (Guinea)',
        'ff_Latn' => 'Fula (Latin)',
        'ff_Latn_BF' => 'Fula (Latin, Burkina Faso)',
        'ff_Latn_CM' => 'Fula (Latin, Kamerun)',
        'ff_Latn_GH' => 'Fula (Latin, Ghana)',
        'ff_Latn_GM' => 'Fula (Latin, Gambia)',
        'ff_Latn_GN' => 'Fula (Latin, Guinea)',
        'ff_Latn_GW' => 'Fula (Latin, Guinea-Bissau)',
        'ff_Latn_LR' => 'Fula (Latin, Liberia)',
        'ff_Latn_MR' => 'Fula (Latin, Mauritania)',
        'ff_Latn_NE' => 'Fula (Latin, Niger)',
        'ff_Latn_NG' => 'Fula (Latin, Nigeria)',
        'ff_Latn_SL' => 'Fula (Latin, Sierra Leone)',
        'ff_Latn_SN' => 'Fula (Latin, Senegal)',
        'ff_MR' => 'Fula (Mauritania)',
        'ff_SN' => 'Fula (Senegal)',
        'fi' => 'Suomi',
        'fi_FI' => 'Suomi (Finlandia)',
        'fo' => 'Faroe',
        'fo_DK' => 'Faroe (Denmark)',
        'fo_FO' => 'Faroe (Kepulauan Faroe)',
        'fr' => 'Prancis',
        'fr_BE' => 'Prancis (Belgia)',
        'fr_BF' => 'Prancis (Burkina Faso)',
        'fr_BI' => 'Prancis (Burundi)',
        'fr_BJ' => 'Prancis (Benin)',
        'fr_BL' => 'Prancis (Saint Barthélemy)',
        'fr_CA' => 'Prancis (Kanada)',
        'fr_CD' => 'Prancis (Kongo - Kinshasa)',
        'fr_CF' => 'Prancis (Republik Afrika Tengah)',
        'fr_CG' => 'Prancis (Kongo - Brazzaville)',
        'fr_CH' => 'Prancis (Swiss)',
        'fr_CI' => 'Prancis (Côte d’Ivoire)',
        'fr_CM' => 'Prancis (Kamerun)',
        'fr_DJ' => 'Prancis (Jibuti)',
        'fr_DZ' => 'Prancis (Aljazair)',
        'fr_FR' => 'Prancis (Prancis)',
        'fr_GA' => 'Prancis (Gabon)',
        'fr_GF' => 'Prancis (Guyana Prancis)',
        'fr_GN' => 'Prancis (Guinea)',
        'fr_GP' => 'Prancis (Guadeloupe)',
        'fr_GQ' => 'Prancis (Guinea Ekuatorial)',
        'fr_HT' => 'Prancis (Haiti)',
        'fr_KM' => 'Prancis (Komoro)',
        'fr_LU' => 'Prancis (Luksemburg)',
        'fr_MA' => 'Prancis (Maroko)',
        'fr_MC' => 'Prancis (Monako)',
        'fr_MF' => 'Prancis (Saint Martin)',
        'fr_MG' => 'Prancis (Madagaskar)',
        'fr_ML' => 'Prancis (Mali)',
        'fr_MQ' => 'Prancis (Martinik)',
        'fr_MR' => 'Prancis (Mauritania)',
        'fr_MU' => 'Prancis (Mauritius)',
        'fr_NC' => 'Prancis (Kaledonia Baru)',
        'fr_NE' => 'Prancis (Niger)',
        'fr_PF' => 'Prancis (Polinesia Prancis)',
        'fr_PM' => 'Prancis (Saint Pierre dan Miquelon)',
        'fr_RE' => 'Prancis (Réunion)',
        'fr_RW' => 'Prancis (Rwanda)',
        'fr_SC' => 'Prancis (Seychelles)',
        'fr_SN' => 'Prancis (Senegal)',
        'fr_SY' => 'Prancis (Suriah)',
        'fr_TD' => 'Prancis (Chad)',
        'fr_TG' => 'Prancis (Togo)',
        'fr_TN' => 'Prancis (Tunisia)',
        'fr_VU' => 'Prancis (Vanuatu)',
        'fr_WF' => 'Prancis (Kepulauan Wallis dan Futuna)',
        'fr_YT' => 'Prancis (Mayotte)',
        'fy' => 'Frisia Barat',
        'fy_NL' => 'Frisia Barat (Belanda)',
        'ga' => 'Irlandia',
        'ga_GB' => 'Irlandia (Inggris Raya)',
        'ga_IE' => 'Irlandia (Irlandia)',
        'gd' => 'Gaelik Skotlandia',
        'gd_GB' => 'Gaelik Skotlandia (Inggris Raya)',
        'gl' => 'Galisia',
        'gl_ES' => 'Galisia (Spanyol)',
        'gu' => 'Gujarat',
        'gu_IN' => 'Gujarat (India)',
        'gv' => 'Manx',
        'gv_IM' => 'Manx (Pulau Man)',
        'ha' => 'Hausa',
        'ha_GH' => 'Hausa (Ghana)',
        'ha_NE' => 'Hausa (Niger)',
        'ha_NG' => 'Hausa (Nigeria)',
        'he' => 'Ibrani',
        'he_IL' => 'Ibrani (Israel)',
        'hi' => 'Hindi',
        'hi_IN' => 'Hindi (India)',
        'hi_Latn' => 'Hindi (Latin)',
        'hi_Latn_IN' => 'Hindi (Latin, India)',
        'hr' => 'Kroasia',
        'hr_BA' => 'Kroasia (Bosnia dan Herzegovina)',
        'hr_HR' => 'Kroasia (Kroasia)',
        'hu' => 'Hungaria',
        'hu_HU' => 'Hungaria (Hungaria)',
        'hy' => 'Armenia',
        'hy_AM' => 'Armenia (Armenia)',
        'ia' => 'Interlingua',
        'ia_001' => 'Interlingua (Dunia)',
        'id' => 'Indonesia',
        'id_ID' => 'Indonesia (Indonesia)',
        'ig' => 'Igbo',
        'ig_NG' => 'Igbo (Nigeria)',
        'ii' => 'Sichuan Yi',
        'ii_CN' => 'Sichuan Yi (Tiongkok)',
        'is' => 'Islandia',
        'is_IS' => 'Islandia (Islandia)',
        'it' => 'Italia',
        'it_CH' => 'Italia (Swiss)',
        'it_IT' => 'Italia (Italia)',
        'it_SM' => 'Italia (San Marino)',
        'it_VA' => 'Italia (Vatikan)',
        'ja' => 'Jepang',
        'ja_JP' => 'Jepang (Jepang)',
        'jv' => 'Jawa',
        'jv_ID' => 'Jawa (Indonesia)',
        'ka' => 'Georgia',
        'ka_GE' => 'Georgia (Georgia)',
        'ki' => 'Kikuyu',
        'ki_KE' => 'Kikuyu (Kenya)',
        'kk' => 'Kazakh',
        'kk_KZ' => 'Kazakh (Kazakhstan)',
        'kl' => 'Kalaallisut',
        'kl_GL' => 'Kalaallisut (Greenland)',
        'km' => 'Khmer',
        'km_KH' => 'Khmer (Kamboja)',
        'kn' => 'Kannada',
        'kn_IN' => 'Kannada (India)',
        'ko' => 'Korea',
        'ko_KP' => 'Korea (Korea Utara)',
        'ko_KR' => 'Korea (Korea Selatan)',
        'ks' => 'Kashmir',
        'ks_Arab' => 'Kashmir (Arab)',
        'ks_Arab_IN' => 'Kashmir (Arab, India)',
        'ks_Deva' => 'Kashmir (Dewanagari)',
        'ks_Deva_IN' => 'Kashmir (Dewanagari, India)',
        'ks_IN' => 'Kashmir (India)',
        'ku' => 'Kurdi',
        'ku_TR' => 'Kurdi (Turki)',
        'kw' => 'Kornish',
        'kw_GB' => 'Kornish (Inggris Raya)',
        'ky' => 'Kirgiz',
        'ky_KG' => 'Kirgiz (Kirgizstan)',
        'lb' => 'Luksemburg',
        'lb_LU' => 'Luksemburg (Luksemburg)',
        'lg' => 'Ganda',
        'lg_UG' => 'Ganda (Uganda)',
        'ln' => 'Lingala',
        'ln_AO' => 'Lingala (Angola)',
        'ln_CD' => 'Lingala (Kongo - Kinshasa)',
        'ln_CF' => 'Lingala (Republik Afrika Tengah)',
        'ln_CG' => 'Lingala (Kongo - Brazzaville)',
        'lo' => 'Lao',
        'lo_LA' => 'Lao (Laos)',
        'lt' => 'Lituavi',
        'lt_LT' => 'Lituavi (Lituania)',
        'lu' => 'Luba-Katanga',
        'lu_CD' => 'Luba-Katanga (Kongo - Kinshasa)',
        'lv' => 'Latvi',
        'lv_LV' => 'Latvi (Latvia)',
        'mg' => 'Malagasi',
        'mg_MG' => 'Malagasi (Madagaskar)',
        'mi' => 'Maori',
        'mi_NZ' => 'Maori (Selandia Baru)',
        'mk' => 'Makedonia',
        'mk_MK' => 'Makedonia (Makedonia Utara)',
        'ml' => 'Malayalam',
        'ml_IN' => 'Malayalam (India)',
        'mn' => 'Mongolia',
        'mn_MN' => 'Mongolia (Mongolia)',
        'mr' => 'Marathi',
        'mr_IN' => 'Marathi (India)',
        'ms' => 'Melayu',
        'ms_BN' => 'Melayu (Brunei)',
        'ms_ID' => 'Melayu (Indonesia)',
        'ms_MY' => 'Melayu (Malaysia)',
        'ms_SG' => 'Melayu (Singapura)',
        'mt' => 'Malta',
        'mt_MT' => 'Malta (Malta)',
        'my' => 'Burma',
        'my_MM' => 'Burma (Myanmar [Burma])',
        'nb' => 'Bokmål Norwegia',
        'nb_NO' => 'Bokmål Norwegia (Norwegia)',
        'nb_SJ' => 'Bokmål Norwegia (Kepulauan Svalbard dan Jan Mayen)',
        'nd' => 'Ndebele Utara',
        'nd_ZW' => 'Ndebele Utara (Zimbabwe)',
        'ne' => 'Nepali',
        'ne_IN' => 'Nepali (India)',
        'ne_NP' => 'Nepali (Nepal)',
        'nl' => 'Belanda',
        'nl_AW' => 'Belanda (Aruba)',
        'nl_BE' => 'Belanda (Belgia)',
        'nl_BQ' => 'Belanda (Belanda Karibia)',
        'nl_CW' => 'Belanda (Curaçao)',
        'nl_NL' => 'Belanda (Belanda)',
        'nl_SR' => 'Belanda (Suriname)',
        'nl_SX' => 'Belanda (Sint Maarten)',
        'nn' => 'Nynorsk Norwegia',
        'nn_NO' => 'Nynorsk Norwegia (Norwegia)',
        'no' => 'Norwegia',
        'no_NO' => 'Norwegia (Norwegia)',
        'om' => 'Oromo',
        'om_ET' => 'Oromo (Etiopia)',
        'om_KE' => 'Oromo (Kenya)',
        'or' => 'Oriya',
        'or_IN' => 'Oriya (India)',
        'os' => 'Ossetia',
        'os_GE' => 'Ossetia (Georgia)',
        'os_RU' => 'Ossetia (Rusia)',
        'pa' => 'Punjabi',
        'pa_Arab' => 'Punjabi (Arab)',
        'pa_Arab_PK' => 'Punjabi (Arab, Pakistan)',
        'pa_Guru' => 'Punjabi (Gurmukhi)',
        'pa_Guru_IN' => 'Punjabi (Gurmukhi, India)',
        'pa_IN' => 'Punjabi (India)',
        'pa_PK' => 'Punjabi (Pakistan)',
        'pl' => 'Polski',
        'pl_PL' => 'Polski (Polandia)',
        'ps' => 'Pashto',
        'ps_AF' => 'Pashto (Afganistan)',
        'ps_PK' => 'Pashto (Pakistan)',
        'pt' => 'Portugis',
        'pt_AO' => 'Portugis (Angola)',
        'pt_BR' => 'Portugis (Brasil)',
        'pt_CH' => 'Portugis (Swiss)',
        'pt_CV' => 'Portugis (Tanjung Verde)',
        'pt_GQ' => 'Portugis (Guinea Ekuatorial)',
        'pt_GW' => 'Portugis (Guinea-Bissau)',
        'pt_LU' => 'Portugis (Luksemburg)',
        'pt_MO' => 'Portugis (Makau DAK Tiongkok)',
        'pt_MZ' => 'Portugis (Mozambik)',
        'pt_PT' => 'Portugis (Portugal)',
        'pt_ST' => 'Portugis (Sao Tome dan Principe)',
        'pt_TL' => 'Portugis (Timor Leste)',
        'qu' => 'Quechua',
        'qu_BO' => 'Quechua (Bolivia)',
        'qu_EC' => 'Quechua (Ekuador)',
        'qu_PE' => 'Quechua (Peru)',
        'rm' => 'Reto-Roman',
        'rm_CH' => 'Reto-Roman (Swiss)',
        'rn' => 'Rundi',
        'rn_BI' => 'Rundi (Burundi)',
        'ro' => 'Rumania',
        'ro_MD' => 'Rumania (Moldova)',
        'ro_RO' => 'Rumania (Rumania)',
        'ru' => 'Rusia',
        'ru_BY' => 'Rusia (Belarus)',
        'ru_KG' => 'Rusia (Kirgizstan)',
        'ru_KZ' => 'Rusia (Kazakhstan)',
        'ru_MD' => 'Rusia (Moldova)',
        'ru_RU' => 'Rusia (Rusia)',
        'ru_UA' => 'Rusia (Ukraina)',
        'rw' => 'Kinyarwanda',
        'rw_RW' => 'Kinyarwanda (Rwanda)',
        'sa' => 'Sanskerta',
        'sa_IN' => 'Sanskerta (India)',
        'sc' => 'Sardinia',
        'sc_IT' => 'Sardinia (Italia)',
        'sd' => 'Sindhi',
        'sd_Arab' => 'Sindhi (Arab)',
        'sd_Arab_PK' => 'Sindhi (Arab, Pakistan)',
        'sd_Deva' => 'Sindhi (Dewanagari)',
        'sd_Deva_IN' => 'Sindhi (Dewanagari, India)',
        'sd_IN' => 'Sindhi (India)',
        'sd_PK' => 'Sindhi (Pakistan)',
        'se' => 'Sami Utara',
        'se_FI' => 'Sami Utara (Finlandia)',
        'se_NO' => 'Sami Utara (Norwegia)',
        'se_SE' => 'Sami Utara (Swedia)',
        'sg' => 'Sango',
        'sg_CF' => 'Sango (Republik Afrika Tengah)',
        'sh' => 'Serbo-Kroasia',
        'sh_BA' => 'Serbo-Kroasia (Bosnia dan Herzegovina)',
        'si' => 'Sinhala',
        'si_LK' => 'Sinhala (Sri Lanka)',
        'sk' => 'Slovak',
        'sk_SK' => 'Slovak (Slovakia)',
        'sl' => 'Sloven',
        'sl_SI' => 'Sloven (Slovenia)',
        'sn' => 'Shona',
        'sn_ZW' => 'Shona (Zimbabwe)',
        'so' => 'Somalia',
        'so_DJ' => 'Somalia (Jibuti)',
        'so_ET' => 'Somalia (Etiopia)',
        'so_KE' => 'Somalia (Kenya)',
        'so_SO' => 'Somalia (Somalia)',
        'sq' => 'Albania',
        'sq_AL' => 'Albania (Albania)',
        'sq_MK' => 'Albania (Makedonia Utara)',
        'sr' => 'Serbia',
        'sr_BA' => 'Serbia (Bosnia dan Herzegovina)',
        'sr_Cyrl' => 'Serbia (Sirilik)',
        'sr_Cyrl_BA' => 'Serbia (Sirilik, Bosnia dan Herzegovina)',
        'sr_Cyrl_ME' => 'Serbia (Sirilik, Montenegro)',
        'sr_Cyrl_RS' => 'Serbia (Sirilik, Serbia)',
        'sr_Latn' => 'Serbia (Latin)',
        'sr_Latn_BA' => 'Serbia (Latin, Bosnia dan Herzegovina)',
        'sr_Latn_ME' => 'Serbia (Latin, Montenegro)',
        'sr_Latn_RS' => 'Serbia (Latin, Serbia)',
        'sr_ME' => 'Serbia (Montenegro)',
        'sr_RS' => 'Serbia (Serbia)',
        'su' => 'Sunda',
        'su_ID' => 'Sunda (Indonesia)',
        'su_Latn' => 'Sunda (Latin)',
        'su_Latn_ID' => 'Sunda (Latin, Indonesia)',
        'sv' => 'Swedia',
        'sv_AX' => 'Swedia (Kepulauan Aland)',
        'sv_FI' => 'Swedia (Finlandia)',
        'sv_SE' => 'Swedia (Swedia)',
        'sw' => 'Swahili',
        'sw_CD' => 'Swahili (Kongo - Kinshasa)',
        'sw_KE' => 'Swahili (Kenya)',
        'sw_TZ' => 'Swahili (Tanzania)',
        'sw_UG' => 'Swahili (Uganda)',
        'ta' => 'Tamil',
        'ta_IN' => 'Tamil (India)',
        'ta_LK' => 'Tamil (Sri Lanka)',
        'ta_MY' => 'Tamil (Malaysia)',
        'ta_SG' => 'Tamil (Singapura)',
        'te' => 'Telugu',
        'te_IN' => 'Telugu (India)',
        'tg' => 'Tajik',
        'tg_TJ' => 'Tajik (Tajikistan)',
        'th' => 'Thai',
        'th_TH' => 'Thai (Thailand)',
        'ti' => 'Tigrinya',
        'ti_ER' => 'Tigrinya (Eritrea)',
        'ti_ET' => 'Tigrinya (Etiopia)',
        'tk' => 'Turkmen',
        'tk_TM' => 'Turkmen (Turkmenistan)',
        'tl' => 'Tagalog',
        'tl_PH' => 'Tagalog (Filipina)',
        'to' => 'Tonga',
        'to_TO' => 'Tonga (Tonga)',
        'tr' => 'Turki',
        'tr_CY' => 'Turki (Siprus)',
        'tr_TR' => 'Turki (Turki)',
        'tt' => 'Tatar',
        'tt_RU' => 'Tatar (Rusia)',
        'ug' => 'Uyghur',
        'ug_CN' => 'Uyghur (Tiongkok)',
        'uk' => 'Ukraina',
        'uk_UA' => 'Ukraina (Ukraina)',
        'ur' => 'Urdu',
        'ur_IN' => 'Urdu (India)',
        'ur_PK' => 'Urdu (Pakistan)',
        'uz' => 'Uzbek',
        'uz_AF' => 'Uzbek (Afganistan)',
        'uz_Arab' => 'Uzbek (Arab)',
        'uz_Arab_AF' => 'Uzbek (Arab, Afganistan)',
        'uz_Cyrl' => 'Uzbek (Sirilik)',
        'uz_Cyrl_UZ' => 'Uzbek (Sirilik, Uzbekistan)',
        'uz_Latn' => 'Uzbek (Latin)',
        'uz_Latn_UZ' => 'Uzbek (Latin, Uzbekistan)',
        'uz_UZ' => 'Uzbek (Uzbekistan)',
        'vi' => 'Vietnam',
        'vi_VN' => 'Vietnam (Vietnam)',
        'wo' => 'Wolof',
        'wo_SN' => 'Wolof (Senegal)',
        'xh' => 'Xhosa',
        'xh_ZA' => 'Xhosa (Afrika Selatan)',
        'yi' => 'Yiddish',
        'yi_001' => 'Yiddish (Dunia)',
        'yo' => 'Yoruba',
        'yo_BJ' => 'Yoruba (Benin)',
        'yo_NG' => 'Yoruba (Nigeria)',
        'zh' => 'Tionghoa',
        'zh_CN' => 'Tionghoa (Tiongkok)',
        'zh_HK' => 'Tionghoa (Hong Kong DAK Tiongkok)',
        'zh_Hans' => 'Tionghoa (Sederhana)',
        'zh_Hans_CN' => 'Tionghoa (Sederhana, Tiongkok)',
        'zh_Hans_HK' => 'Tionghoa (Sederhana, Hong Kong DAK Tiongkok)',
        'zh_Hans_MO' => 'Tionghoa (Sederhana, Makau DAK Tiongkok)',
        'zh_Hans_SG' => 'Tionghoa (Sederhana, Singapura)',
        'zh_Hant' => 'Tionghoa (Tradisional)',
        'zh_Hant_HK' => 'Tionghoa (Tradisional, Hong Kong DAK Tiongkok)',
        'zh_Hant_MO' => 'Tionghoa (Tradisional, Makau DAK Tiongkok)',
        'zh_Hant_TW' => 'Tionghoa (Tradisional, Taiwan)',
        'zh_MO' => 'Tionghoa (Makau DAK Tiongkok)',
        'zh_SG' => 'Tionghoa (Singapura)',
        'zh_TW' => 'Tionghoa (Taiwan)',
        'zu' => 'Zulu',
        'zu_ZA' => 'Zulu (Afrika Selatan)',
    ],
];
